@@ -171,12 +171,13 @@ bool Basic_buffer::pseek( Point & p, int n ) const throw()
 
 bool Basic_buffer::pvalid( Point & p ) const throw()
   {
-  if( p < bof() ) { p = bof(); return false; }
-  if( p > eof() ) { p = eof(); return false; }
-  if( p.col > 0 && p.col >= (int)data[p.line].size() )
-    { p.col = data[p.line].size() - 1; return false; }
-  if( p.col < 0 ) { p.col = 0; return false; }
-  return true;
+  if( p < bof() ) p = bof();
+  else if( p > eof() ) p = eof();
+  else if( p.col < 0 ) p.col = 0;
+  else if( p.col > 0 && p.col >= (int)data[p.line].size() && p != eof() )
+    p.col = data[p.line].size() - 1;
+  else return true;
+  return false;
   }
 
 
