@@ -28,14 +28,15 @@
 namespace Block {
 
 Buffer *_bufferp = 0, *saved_bufferp = 0;
-Point anchor, _begin, _end, saved_begin, saved_end;
-bool _marking = false;
+Point _anchor, _begin, _end, saved_begin, saved_end;
 
 
 void enable_marking( Buffer & buffer, const Point & p ) throw()
-  {
-  _bufferp = &buffer; _begin = p; anchor = p; _end = Point(); _marking = true;
-  }
+  { _bufferp = &buffer; _begin = p; _anchor = p; _end = Point(); }
+
+void disable_marking() throw() { _anchor = Point(); }
+
+bool marking() throw() { return ( _anchor != Point() ); }
 
 } // end namespace Block
 
@@ -45,6 +46,8 @@ Buffer & Block::buffer() throw() { return *_bufferp; }
 bool Block::same_buffer( const Buffer & buffer ) throw()
   { return &buffer == _bufferp; }
 
+Point & Block::anchor() throw() { return _anchor; }
+
 Point & Block::begin() throw() { return _begin; }
 
 Point & Block::end() throw() { return _end; }
@@ -70,27 +73,32 @@ void Block::save_block_position() throw()
 
 
 void Block::restore_block_position() throw()
-  { _bufferp = saved_bufferp; _begin = saved_begin; _end = saved_end; }
+  {
+  _bufferp = saved_bufferp; _begin = saved_begin; _end = saved_end;
+  if( _bufferp )
+    { _bufferp->pvalid( _begin ); _bufferp->pvalid( _end ); }
+  disable_marking();
+  }
 
 
 void Block::reset() throw()
-  { _bufferp = 0; _begin = _end = Point(); _marking = false; }
+  { _bufferp = 0; _begin = _end = Point(); disable_marking(); }
 
 
 void Block::set_block( Buffer & buffer, const Point & p1, const Point & p2 ) throw()
-  { _bufferp = &buffer; _begin = p1; _end = p2; _marking = false; }
+  { _bufferp = &buffer; _begin = p1; _end = p2; disable_marking(); }
 
 
 void Block::set_begin( Buffer & buffer, const Point & p ) throw()
   {
-  _begin = p; _marking = false;
+  _begin = p; disable_marking();
   if( &buffer != _bufferp ) { _bufferp = &buffer; _end = Point(); }
   }
 
 
 void Block::set_end( Buffer & buffer, const Point & p ) throw()
   {
-  _end = p; _marking = false;
+  _end = p; disable_marking();
   if( &buffer != _bufferp ) { _bufferp = &buffer; _begin = Point(); }
   }
 
@@ -98,10 +106,10 @@ void Block::set_end( Buffer & buffer, const Point & p ) throw()
 bool Block::follow_marking( const Buffer & buffer, const Point & p ) throw()
   {
   static Point old_p;
-  if( _marking && same_buffer( buffer ) && p != old_p )
+  if( marking() && same_buffer( buffer ) && p != old_p )
     {
-    if( p < anchor ) _begin = p; else _begin = anchor;
-    if( p > anchor ) _end = p; else _end = anchor;
+    if( p < _anchor ) _begin = p; else _begin = _anchor;
+    if( p > _anchor ) _end = p; else _end = _anchor;
     old_p = p;
     return true;
     }
@@ -113,14 +121,14 @@ const char * Block::toggle_marking( Buffer & buffer, const Point & p ) throw()
   {
   const char * const str[2] = { "Selection started.", "Selection cleared." };
   const char * msg = 0;
-  if( !_marking )
+  if( marking() )
     {
-    if( in_block_or_end( buffer, p ) ) { reset(); msg = str[1]; }
+    if( same_buffer( buffer ) ) { if( valid() ) disable_marking(); else reset(); }
     else { enable_marking( buffer, p ); msg = str[0]; }
     }
   else
     {
-    if( same_buffer( buffer ) ) { if( valid() ) _marking = false; else reset(); }
+    if( in_block_or_end( buffer, p ) ) { reset(); msg = str[1]; }
     else { enable_marking( buffer, p ); msg = str[0]; }
     }
   return msg;
@@ -152,7 +160,7 @@ bool Block::delete_block() throw()
     buffer.reset_appendable();
     const bool result = buffer.pdelb( _begin, _end );
     buffer.reset_appendable();
-    _bufferp = &buffer; _end = _begin; _marking = false;
+    _bufferp = &buffer; _end = _begin; disable_marking();
     return result;
     }
   return false;
