@@ -55,7 +55,11 @@ std::vector< Point * > & get_marks_and_pointers( Buffer & b ) throw()
     if( &b == &bh.buffer() ) v.push_back( &bh.pointer );
     }
   if( Block::same_buffer( b ) )
-    { v.push_back( &Block::begin() ); v.push_back( &Block::end() ); }
+    {
+    v.push_back( &Block::anchor() );
+    v.push_back( &Block::begin() );
+    v.push_back( &Block::end() );
+    }
   return v;
   }
 
@@ -183,6 +187,7 @@ bool Buffer::save( const std::string * namep, bool set_name, bool append,
            ( _name.size() && !stat( _name.c_str(), &st ) ) )
          mode = st.st_mode;
 
+  const bool had_name = ( _name.size() > 0 );
   bool same_name = set_name;
   if( set_name )
     {
@@ -215,7 +220,8 @@ bool Buffer::save( const std::string * namep, bool set_name, bool append,
   FILE *f = 0;
   if( File::make_path( *namep ) )
     f = std::fopen( namep->c_str(), append ? "a" : "w" );
-  if( !f ) throw Error( "Error opening file" );
+  if( !f )
+    { if( !had_name ) { _name.clear(); } throw Error( "Error opening file" ); }
   if( mode ) fchmod( fileno( f ), mode );
 
   if( !this->pisvalid( p1 ) ) p1 = this->bof();
@@ -280,7 +286,7 @@ bool Buffer::pputb( Point & p, const Basic_buffer & b, const Point & p1,
   Basic_buffer::pputb( p, b, p1, p2 );
   if( save_change )
     {
-    Change_history::Record r( _modified );
+    Change_history::Record r( p0, _modified );
     r.add_atom( Change_history::Atom( p0, p ) );
     change_history.add_record( *this, r );
     _modified = true;
@@ -330,7 +336,7 @@ bool Buffer::pputc( Point & p, const unsigned char ch ) throw()
   else
     {
     const Point p0 = p;
-    Change_history::Record r( _modified );
+    Change_history::Record r( p0, _modified );
     if( options.overwrite && p != eol( p ) )
       {
       tmp.pputc( dummy, (*this)[p] );
@@ -374,13 +380,14 @@ bool Buffer::pputc( Point & p, const unsigned char ch ) throw()
 
 
 // delete block at [p1,p2)
-bool Buffer::pdelb( const Point & p1, const Point & p2, const bool save_change ) throw()
+bool Buffer::pdelb( const Point & p1, const Point & p2, const int save_change ) throw()
   {
   if( options.read_only || p1 >= p2 || !pisvalid( p1 ) || !pisvalid( p2 ) )
     return false;
   if( save_change )
     {
-    Change_history::Record r( _modified );
+    const Point & p0 = (save_change != 2) ? p1 : p2;
+    Change_history::Record r( p0, _modified );
     r.add_atom( Change_history::Atom( p1, p2, *this ) );
     change_history.add_record( *this, r );
     _modified = true;
@@ -403,11 +410,12 @@ bool Buffer::pdelb( const Point & p1, const Point & p2, const bool save_change )
   }
 
 
-// delete char at 'p'
-bool Buffer::pdelc( const Point & p ) throw()
+// delete char at 'p', or at '--p' if back is true
+bool Buffer::pdelc( Point & p, const bool back ) throw()
   {
   Point p1 = p;
-  return ( pnext( p1 ) && pdelb( p, p1 ) );
+  if( back ) return ( pprev( p ) && pdelb( p, p1, 2 ) );
+  else return ( pnext( p1 ) && pdelb( p, p1 ) );
   }
 
 
@@ -433,7 +441,7 @@ bool Buffer::undo( Point & p ) throw()
     if( atom.begin < atom.end )
       {
       tmp = new Basic_buffer( *this, atom.begin, atom.end );
-      pdelb( atom.begin, atom.end, false );
+      pdelb( atom.begin, atom.end, 0 );
       }
     atom.end = atom.begin;
     if( atom.bbp )
@@ -442,8 +450,8 @@ bool Buffer::undo( Point & p ) throw()
       delete( atom.bbp );
       }
     atom.bbp = tmp;
-    if( i == 0 || p > atom.begin ) p = atom.begin;
     }
+  p = rec.pointer;
   std::swap( _modified, rec.modified );
   --change_history.index;
   return true;
@@ -463,17 +471,18 @@ bool Buffer::redo( Point & p ) throw()
     if( atom.begin < atom.end )
       {
       tmp = new Basic_buffer( *this, atom.begin, atom.end );
-      pdelb( atom.begin, atom.end, false );
+      pdelb( atom.begin, atom.end, 0 );
+      p = atom.begin;
       }
     atom.end = atom.begin;
     if( atom.bbp )
       {
       pputb( atom.end, *atom.bbp, atom.bbp->bof(), atom.bbp->eof(), false );
-      delete( atom.bbp );
+      p = atom.end; delete( atom.bbp );
       }
     atom.bbp = tmp;
-    if( i == 0 || p > atom.begin ) p = atom.begin;
     }
+  if( p.line > rec.pointer.line ) p = rec.pointer;
   std::swap( _modified, rec.modified );
   return true;
   }
