@@ -152,10 +152,12 @@ class Buffer : public Basic_buffer
 
     struct Record
       {
+      Point pointer;		// Pointer position before the change
       mutable bool modified;	// Status of modified flag before this record
       std::vector< Atom > atom_vector;
 
-      Record( const bool m ) throw() : modified( m ) {}
+      Record( const Point & p, const bool m ) throw()
+        : pointer( p ), modified( m ) {}
       void add_atom( const Atom & a ) throw() { atom_vector.push_back( a ); }
       };
 
@@ -211,15 +213,16 @@ public:
   const std::string & name() const throw() { return _name; }
   const std::string & uname() const throw();
 
-  // insert block b.[p1,p2) at p and move next
+       // insert block b.[p1,p2) at p and move next
   bool pputb( Point & p, const Basic_buffer & b, const Point & p1,
               const Point & p2, const bool save_change = true ) throw();
-  // put char and move next
+       // put char and move next
   bool pputc( Point & p, const unsigned char ch ) throw();
 
-  // delete block at [p1,p2)
-  bool pdelb( const Point & p1, const Point & p2, const bool save_change = true ) throw();
-  bool pdelc( const Point & p ) throw();	// delete char at 'p'
+       // delete block at [p1,p2)
+  bool pdelb( const Point & p1, const Point & p2, const int save_change = 1 ) throw();
+       // delete char at 'p', or at '--p' if back is true
+  bool pdelc( Point & p, const bool back = false ) throw();
   bool pdell( Point & p ) throw();	// delete line and set 'p' to bol()
 
   bool undo( Point & p ) throw();
@@ -240,7 +243,7 @@ public:
   Point pcursor;	// buffer coordinates of current buffer character
 
   Buffer_handle( Buffer & buffer, const int line = 0 ) throw()
-    : _bufferp( &buffer ), top_left( 0, 0 ), cursor( line, 0 ),
+    : _bufferp( &buffer ), top_left( line, 0 ), cursor( line, 0 ),
       pointer( line, 0 ), pcursor( line, 0 ) {}
 
   Buffer & buffer() throw() { return *_bufferp; }
