@@ -39,13 +39,13 @@
 
 namespace {
 
-// Date of this version: 2005-09-16
+// Date of this version: 2005-10-10
 
 const char * invocation_name = 0;
 const char * const Program_name     = "GNU Moe";
 const char * const program_name     = "moe";
 const char * const config_file_name = "moerc";
-const char * const program_version  = "0.4";
+const char * const program_version  = "0.5";
 const char * const program_year     = "2005";
 
 
@@ -130,6 +130,7 @@ bool use_it_anyway( std::string name ) throw()
 
 int process_config_file() throw()
   {
+  std::fprintf( stderr, "\n" );
   std::string name = RC::home_directory();
   if( name.size() )
     {
@@ -193,7 +194,12 @@ int main( int argc, char *argv[] ) throw()
   if( !retval )
     {
     retval = RC::process_options( argc, argv );
-    if( retval == 2 ) RC::show_error( "bad filename, not a regular file" );
+    if( retval == 2 )
+      {
+      std::fprintf( stderr, "Warning: non-regular files will be ignored.\n" );
+      std::fprintf( stderr, "Press RETURN to continue, Ctrl-C to abort. " );
+      std::fgetc( stdin ); std::fprintf( stderr, "\n" ); retval = 0;
+      }
     else if( retval ) RC::show_error( 0, 0, true );
     }
   if( retval ) return retval;
