@@ -125,8 +125,7 @@ bool File::file_menu( const std::string & prompt, std::string & name ) throw()
   std::string dirname, basename;
   std::vector< std::string > name_vector;
 
-  if( name.size() >= 2 && !name.compare( 0, 2, "~/" ) )
-    name.replace( 0, 1, RC::home_directory() );
+  tilde_expansion( name );
   split_filename( name, dirname, basename );
   basename += '*';
 
@@ -235,7 +234,7 @@ bool File::is_regular( const std::string & name, const bool quiet ) throw()
     const int i = stat( name.c_str(), &st );
     if( ( i == 0 && S_ISREG( st.st_mode ) ) ||
         ( i == -1 && errno == ENOENT ) ) return true;
-    if( !quiet ) Screen::show_message( "Not a regular file", true );
+    if( !quiet ) Screen::show_message( "Not a regular file", true, true );
     }
   return false;
   }
@@ -278,6 +277,15 @@ const std::string & File::my_basename( const std::string & name ) throw()
 
 bool File::test_slash_filename( std::string & name ) throw()
   {
+  tilde_expansion( name );
   return ( !name.size() ||
            ( valid_filename( name ) && !append_slash_if_dir( name ) ) );
   }
+
+
+bool File::tilde_expansion( std::string & name ) throw()
+  {
+  if( name.size() >= 2 && !name.compare( 0, 2, "~/" ) )
+    { name.replace( 0, 1, RC::home_directory() ); return true; }
+  return false;
+  }
