@@ -415,11 +415,12 @@ int RC::process_rcfile( const std::string & name ) throw()
   }
 
 
-// Returns 0 for success, 1 for invalid option, 2 for a no regular file.
+// Returns 0 for success, 1 for invalid option, 2 if non-regular files given.
 //
 int RC::process_options( int argc, char *argv[] ) throw()
   {
   int line = 0, optind;
+  bool non_regular_found = false;
 
   std::fprintf( stderr, "Processing options... " );
   std::fflush( stderr );
@@ -442,8 +443,14 @@ int RC::process_options( int argc, char *argv[] ) throw()
     {
     while( optind < argc )	// Process input files and file options
       {
-      const std::string name = argv[optind++];
-      if( !File::is_regular( name, true ) ) return 2;
+      std::string name = argv[optind++];
+      File::tilde_expansion( name );
+      const bool regular = File::is_regular( name, true );
+      if( !regular )
+        {
+        std::fprintf( stderr, "Warning: `%s' is not a regular file\n", name.c_str() );
+        name.clear(); non_regular_found = true;
+        }
       const int i = bufhandle_vector.add_handle( _default_buffer_options, &name, -1, line );
       line = 0;
       Buffer & buffer = bufhandle_vector[i].buffer();
@@ -460,6 +467,7 @@ int RC::process_options( int argc, char *argv[] ) throw()
                                             0, &buffer.options );
         if( n == 0 ) return 1; else if( n == 2 ) ++optind;
         }
+      if( !regular ) bufhandle_vector.delete_handle( i );
       }
     }
   catch( Buffer::Error e ) { std::fprintf( stderr, "%s\n", e.s ); return 1; }
@@ -469,7 +477,7 @@ int RC::process_options( int argc, char *argv[] ) throw()
   catch( Buffer::Error e ) { std::fprintf( stderr, "%s\n", e.s ); return 1; }
 
   std::fprintf( stderr, "done\n" );
-  return 0;
+  if( non_regular_found ) return 2; else return 0;
   }
 
 
