@@ -531,7 +531,7 @@ int Screen::user_loop() throw()
       case KEY_F(8) : window_vector.redo(); break;
       case KEY_F(9) : window_vector.copy_block(); break;
       case KEY_F(10): Menu::options_menu( w.buffer(), key ); break;
-      case KEY_BACKSPACE: window_vector.backspace(); break;
+      case KEY_BACKSPACE: window_vector.delete_char( true ); break;
       case KEY_DC   : window_vector.delete_char(); break;
       case KEY_IC   : w.buffer().options.overwrite = !w.buffer().options.overwrite;
                       window_vector.show_status_lines( &w.buffer() ); break;
