@@ -1,4 +1,4 @@
-/*  Moe - My Own Editor
+/*  GNU Moe - My Own Editor
     Copyright (C) 2005 Antonio Diaz Diaz.
 
     This program is free software; you can redistribute it and/or modify
@@ -41,7 +41,8 @@ void clock_handler( const int sig ) throw();		// updates the clock
 // Returns the size of the result string, 0 if none, -1 if aborted.
 //
 int get_string( const std::string & prompt,
-                std::vector< std::string > & history, const bool usetab = false ) throw();
+                std::vector< std::string > & history,
+                const bool allow_copy = false, const bool usetab = false ) throw();
 
 
 int height() throw();
