@@ -30,11 +30,12 @@
 #include "window.h"
 
 
-Window::Window( const int tl, const int h, Buffer_handle & bh ) throw()
+Window::Window( const int tl, const int h, Buffer_handle & bh, const bool center ) throw()
   : _top_line( tl ), _height( h ), bhp( &bh )
   {
   bhp->buffer().pvalid( bhp->pointer );
-  update_points( bhp->pointer, false );
+  if( center ) center_cursor();
+  else update_points( bhp->pointer, false );
   }
 
 
@@ -355,15 +356,15 @@ void Window::update_points( const Point & to, const bool show,
     }
 
   const Point rc = relative_cursor();
-  if( rc.line >= _height - 1 )
+  if( rc.line > _height - 2 )
     {
-    const int d = center ? ( _height - 1 ) / 2 : _height - 2;
+    const int d = center ? ( _height - 2 ) / 2 : _height - 2;
     tl.line = std::max( 0, c.line - d );
     }
   else if( rc.line < 1 )
     {
-    tl.line = c.line;
-    if( center ) { tl.line -= ( _height - 1 ) / 2; tl.cut(); }
+    const int d = center ? ( _height - 2 ) / 2 : 0;
+    tl.line = std::max( 0, c.line - d );
     }
   if( rc.col >= Screen::width() ) tl.col = c.col - Screen::width() + 1;
   else if( rc.col < 0 ) tl.col = std::max( 0, c.col - ( Screen::width() / 2 ) );
