@@ -23,7 +23,7 @@ class Window
 
 public:
   static const int min_height = 4;
-  Window( const int tl, const int h, Buffer_handle & bh ) throw();
+  Window( const int tl, const int h, Buffer_handle & bh, const bool center ) throw();
 
   Buffer & buffer() const throw() { return bhp->buffer(); }
   Buffer_handle & buffer_handle() const throw() { return *bhp; }
@@ -89,8 +89,7 @@ public:
   int windows() const throw() { return data.size(); }
 
   void add_char( unsigned char ch, const bool force = false ) throw();
-  void backspace() throw();
-  void delete_char() throw();
+  void delete_char( const bool back = false ) throw();
   void delete_line() throw();
   void delete_block() throw();
   void copy_block() throw();
