@@ -80,6 +80,7 @@ int Window_vector::load( int new_size ) throw()
   {
   const int handles = bufhandle_vector.handles();
   const bool toggle = ( new_size < 0 && handles > 1 );
+  const bool center = ( data.size() == 0 );		// center all on init
 
   if( !handles ) { _curwin = 0; data.clear(); return 0; }
   if( new_size == 0 ) new_size = data.size();
@@ -99,10 +100,10 @@ int Window_vector::load( int new_size ) throw()
   int i = 0, y = 0;
   while( i < new_size - 1 )
     {
-    data.push_back( Window( y, wheight, bufhandle_vector[i] ) );
+    data.push_back( Window( y, wheight, bufhandle_vector[i], center ) );
     ++i; y += wheight;
     }
-  data.push_back( Window( y, Screen::height() - y, bufhandle_vector[i] ) );
+  data.push_back( Window( y, Screen::height() - y, bufhandle_vector[i], center ) );
   if( toggle && new_size == 1 ) data[0].center_cursor();
   for( i = 0; i < new_size; ++i ) data[i].repaint();
   return data.size();
@@ -260,21 +261,12 @@ void Window_vector::add_char( unsigned char ch, const bool force ) throw()
   }
 
 
-void Window_vector::backspace() throw()
+void Window_vector::delete_char( const bool back ) throw()
   {
   Window & w = data[_curwin];
   Point & p = w.buffer_handle().pointer;
 
-  if( !read_only( w.buffer() ) && w.buffer().pprev( p ) && w.buffer().pdelc( p ) )
-    { update_points( data, &w.buffer() ); repaint( &w.buffer() ); }
-  }
-
-
-void Window_vector::delete_char() throw()
-  {
-  Window & w = data[_curwin];
-
-  if( !read_only( w.buffer() ) && w.buffer().pdelc( w.buffer_handle().pointer ) )
+  if( !read_only( w.buffer() ) && w.buffer().pdelc( p, back ) )
     { update_points( data, &w.buffer() ); repaint( &w.buffer() ); }
   }
 
@@ -365,6 +357,8 @@ void Window_vector::indent_block() throw()
     return;
   Point p = Block::begin();
   bool first_post = true;
+  const bool ow = buffer.options.overwrite;
+  buffer.options.overwrite = false;
   buffer.reset_appendable();
   while( buffer.bol( p ) < Block::end() )
     {
@@ -377,6 +371,7 @@ void Window_vector::indent_block() throw()
     ++p.line;
     }
   buffer.reset_appendable();
+  buffer.options.overwrite = ow;
   update_points( data, &buffer ); repaint( &buffer );
   }
 
@@ -398,6 +393,8 @@ void Window_vector::unindent_block() throw()
   if( fail ) { Screen::show_message( "Can't unindent more" ); return; }
 
   bool first_post = true;
+  const bool ow = buffer.options.overwrite;
+  buffer.options.overwrite = false;
   buffer.reset_appendable();
   p = Block::begin();
   while( buffer.bol( p ) < Block::end() )
@@ -411,7 +408,7 @@ void Window_vector::unindent_block() throw()
         if( col > target_col )
           {
           if( first_post ) first_post = false; else buffer.force_append();
-          buffer.pdelc( Point( p.line, p.col - 1 ) );
+          buffer.pdelc( p, true );
           }
         else if( col < target_col )
           {
@@ -423,6 +420,7 @@ void Window_vector::unindent_block() throw()
     ++p.line;
     }
   buffer.reset_appendable();
+  buffer.options.overwrite = ow;
   update_points( data, &buffer ); repaint( &buffer );
   }
 
@@ -506,7 +504,7 @@ void Window_vector::reformat() throw()
         { tmp.pputc( dummy, ch ); dummy = tmp.eof(); space = false; }
       else if( !space ) { tmp.pputc( dummy, ' ' ); space = true; }
       }
-    if( space ) { tmp.pprev( dummy ); tmp.pdelc( dummy ); }
+    if( space ) tmp.pdelc( dummy, true );
     if( dummy != tmp.bol( dummy ) ) tmp.pputc( dummy, '\n' );
     bool change = ( tmp.eof().line != ( eop.line - bop.line ) );
     if( !change )
